@@ -21,22 +21,25 @@ The main entry point is the ``SimpleDenseSearcher`` class.
 
 import os
 from dataclasses import dataclass
-from typing import Dict, List, Union, Optional
+from typing import Dict, List, Union, Optional, Tuple
 
 import numpy as np
 import pandas as pd
 
-from transformers import (AutoModel, AutoTokenizer, BertModel, BertTokenizer,  BertTokenizerFast,
+from transformers import (AutoModel, AutoTokenizer, BertModel, BertTokenizer, BertTokenizerFast,
                           DPRQuestionEncoder, DPRQuestionEncoderTokenizer, RobertaTokenizer)
 from transformers.file_utils import is_faiss_available, requires_backends
 
 from pyserini.util import (download_encoded_queries, download_prebuilt_index,
                            get_dense_indexes_info, get_sparse_index)
-from pyserini.search import SimpleSearcher, Document
+from pyserini.search import SimpleSearcher
+from pyserini.index import Document
 
 from ._model import AnceEncoder
 import torch
 
+from ..encode import PcaEncoder
+
 if is_faiss_available():
     import faiss
 
@@ -147,7 +150,7 @@ class BprQueryEncoder(QueryEncoder):
         if encoded_query_dir:
             self.embedding = self._load_embeddings(encoded_query_dir)
             self.has_encoded_query = True
-        
+
         if encoder_dir:
             self.device = device
             self.model = DPRQuestionEncoder.from_pretrained(encoder_dir)
@@ -164,25 +167,27 @@ class BprQueryEncoder(QueryEncoder):
             embeddings = self.model(input_ids["input_ids"]).pooler_output.detach().cpu()
             dense_embeddings = embeddings.numpy()
             sparse_embeddings = self.convert_to_binary_code(embeddings).numpy()
-            return {'dense':dense_embeddings.flatten(), 'sparse':sparse_embeddings.flatten()}
+            return {'dense': dense_embeddings.flatten(), 'sparse': sparse_embeddings.flatten()}
         else:
             return super().encode(query)
-    
+
     def convert_to_binary_code(self, input_repr: torch.Tensor):
         return input_repr.new_ones(input_repr.size()).masked_fill_(input_repr < 0, -1.0)
-    
+
     @staticmethod
     def _load_embeddings(encoded_query_dir):
         df = pd.read_pickle(os.path.join(encoded_query_dir, 'embedding.pkl'))
         ret = {}
-        for text, dense, sparse in zip(df['text'].tolist(), df['dense_embedding'].tolist(), df['sparse_embedding'].tolist()):
+        for text, dense, sparse in zip(df['text'].tolist(), df['dense_embedding'].tolist(),
+                                       df['sparse_embedding'].tolist()):
             ret[text] = {'dense': dense, 'sparse': sparse}
         return ret
 
 
 class DkrrDprQueryEncoder(QueryEncoder):
 
-    def __init__(self, encoder_dir: str = None, encoded_query_dir: str = None, device: str = 'cpu', prefix: str = "question:"):
+    def __init__(self, encoder_dir: str = None, encoded_query_dir: str = None, device: str = 'cpu',
+                 prefix: str = "question:"):
         super().__init__(encoded_query_dir)
         self.device = device
         self.model = BertModel.from_pretrained(encoder_dir)
@@ -204,7 +209,7 @@ class DkrrDprQueryEncoder(QueryEncoder):
             inputs = self.tokenizer(query, return_tensors='pt', max_length=40, padding="max_length")
             inputs.to(self.device)
             outputs = self.model(input_ids=inputs["input_ids"],
-                                attention_mask=inputs["attention_mask"])
+                                 attention_mask=inputs["attention_mask"])
             embeddings = self._mean_pooling(outputs, inputs['attention_mask']).detach().cpu().numpy()
             return embeddings.flatten()
         else:
@@ -222,6 +227,7 @@ class AnceQueryEncoder(QueryEncoder):
             self.model.to(self.device)
             self.tokenizer = RobertaTokenizer.from_pretrained(tokenizer_name or encoder_dir)
             self.has_model = True
+            self.tokenizer.do_lower_case = True
         if (not self.has_model) and (not self.has_encoded_query):
             raise Exception('Neither query encoder model nor encoded queries provided. Please provide at least one')
 
@@ -241,6 +247,35 @@ class AnceQueryEncoder(QueryEncoder):
         else:
             return super().encode(query)
 
+    def prf_encode(self, query: str):
+        if self.has_model:
+            inputs = self.tokenizer(
+                [query],
+                max_length=512,
+                padding='longest',
+                truncation=True,
+                add_special_tokens=False,
+                return_tensors='pt'
+            )
+            inputs.to(self.device)
+            embeddings = self.model(inputs["input_ids"]).detach().cpu().numpy()
+            return embeddings.flatten()
+        else:
+            return super().encode(query)
+
+    def prf_batch_encode(self, query: List[str]):
+        inputs = self.tokenizer(
+            query,
+            max_length=512,
+            padding='longest',
+            truncation=True,
+            add_special_tokens=False,
+            return_tensors='pt'
+        )
+        inputs.to(self.device)
+        embeddings = self.model(inputs["input_ids"]).detach().cpu().numpy()
+        return embeddings
+
 
 class AutoQueryEncoder(QueryEncoder):
 
@@ -295,6 +330,13 @@ class DenseSearchResult:
     score: float
 
 
+@dataclass
+class PRFDenseSearchResult:
+    docid: str
+    score: float
+    vectors: [float]
+
+
 class SimpleDenseSearcher:
     """Simple Searcher for dense representation
 
@@ -304,16 +346,17 @@ class SimpleDenseSearcher:
         Path to faiss index directory.
     """
 
-    def __init__(self, index_dir: str, query_encoder: Union[QueryEncoder, str], prebuilt_index_name: Optional[str] = None):
+    def __init__(self, index_dir: str, query_encoder: Union[QueryEncoder, str],
+                 prebuilt_index_name: Optional[str] = None):
         requires_backends(self, "faiss")
-        if isinstance(query_encoder, QueryEncoder):
+        if isinstance(query_encoder, QueryEncoder) or isinstance(query_encoder, PcaEncoder):
             self.query_encoder = query_encoder
         else:
             self.query_encoder = self._init_encoder_from_str(query_encoder)
         self.index, self.docids = self.load_index(index_dir)
         self.dimension = self.index.d
         self.num_docs = self.index.ntotal
-        
+
         assert self.docids is None or self.num_docs == len(self.docids)
         if prebuilt_index_name:
             sparse_index = get_sparse_index(prebuilt_index_name)
@@ -350,61 +393,89 @@ class SimpleDenseSearcher:
         """Display information about available prebuilt indexes."""
         get_dense_indexes_info()
 
-    def search(self, query: str, k: int = 10, threads: int = 1) -> List[DenseSearchResult]:
+    def search(self, query: Union[str, np.ndarray], k: int = 10, threads: int = 1, return_vector: bool = False) \
+            -> Union[List[DenseSearchResult], Tuple[np.ndarray, List[PRFDenseSearchResult]]]:
         """Search the collection.
 
         Parameters
         ----------
-        query : str
-            query text
+        query : Union[str, np.ndarray]
+            query text or query embeddings
         k : int
             Number of hits to return.
         threads : int
             Maximum number of threads to use for intra-query search.
+        return_vector : bool
+            Return the results with vectors
         Returns
         -------
-        List[DenseSearchResult]
-            List of search results.
+        Union[List[DenseSearchResult], Tuple[np.ndarray, List[PRFDenseSearchResult]]]
+            Either returns a list of search results.
+            Or returns the query vector with the list of PRF dense search results with vectors.
         """
-        emb_q = self.query_encoder.encode(query)
-        assert len(emb_q) == self.dimension
-        emb_q = emb_q.reshape((1, len(emb_q)))
+        if isinstance(query, str):
+            emb_q = self.query_encoder.encode(query)
+            assert len(emb_q) == self.dimension
+            emb_q = emb_q.reshape((1, len(emb_q)))
+        else:
+            emb_q = query
         faiss.omp_set_num_threads(threads)
-        distances, indexes = self.index.search(emb_q, k)
-        distances = distances.flat
-        indexes = indexes.flat
-        return [DenseSearchResult(self.docids[idx], score)
-                for score, idx in zip(distances, indexes) if idx != -1]
+        if return_vector:
+            distances, indexes, vectors = self.index.search_and_reconstruct(emb_q, k)
+            vectors = vectors[0]
+            distances = distances.flat
+            indexes = indexes.flat
+            return emb_q, [PRFDenseSearchResult(self.docids[idx], score, vector)
+                           for score, idx, vector in zip(distances, indexes, vectors) if idx != -1]
+        else:
+            distances, indexes = self.index.search(emb_q, k)
+            distances = distances.flat
+            indexes = indexes.flat
+            return [DenseSearchResult(self.docids[idx], score)
+                    for score, idx in zip(distances, indexes) if idx != -1]
 
-    def batch_search(self, queries: List[str], q_ids: List[str], k: int = 10, threads: int = 1) \
-            -> Dict[str, List[DenseSearchResult]]:
+    def batch_search(self, queries: Union[List[str], np.ndarray], q_ids: List[str], k: int = 10,
+                     threads: int = 1, return_vector: bool = False) \
+            -> Union[Dict[str, List[DenseSearchResult]], Tuple[np.ndarray, Dict[str, List[PRFDenseSearchResult]]]]:
         """
 
         Parameters
         ----------
-        queries : List[str]
-            List of query texts
+        queries : Union[List[str], np.ndarray]
+            List of query texts or list of query embeddings
         q_ids : List[str]
             List of corresponding query ids.
         k : int
             Number of hits to return.
         threads : int
             Maximum number of threads to use.
+        return_vector : bool
+            Return the results with vectors
 
         Returns
         -------
-        Dict[str, List[DenseSearchResult]]
-            Dictionary holding the search results, with the query ids as keys and the corresponding lists of search
-            results as the values.
+        Union[Dict[str, List[DenseSearchResult]], Tuple[np.ndarray, Dict[str, List[PRFDenseSearchResult]]]]
+            Either returns a dictionary holding the search results, with the query ids as keys and the
+            corresponding lists of search results as the values.
+            Or returns a tuple with ndarray of query vectors and a dictionary of PRF Dense Search Results with vectors
         """
-        q_embs = np.array([self.query_encoder.encode(q) for q in queries])
-        n, m = q_embs.shape
-        assert m == self.dimension
+        if isinstance(queries, np.ndarray):
+            q_embs = queries
+        else:
+            q_embs = np.array([self.query_encoder.encode(q) for q in queries])
+            n, m = q_embs.shape
+            assert m == self.dimension
         faiss.omp_set_num_threads(threads)
-        D, I = self.index.search(q_embs, k)
-        return {key: [DenseSearchResult(self.docids[idx], score)
-                      for score, idx in zip(distances, indexes) if idx != -1]
-                for key, distances, indexes in zip(q_ids, D, I)}
+        if return_vector:
+            D, I, V = self.index.search_and_reconstruct(q_embs, k)
+            return q_embs, {key: [PRFDenseSearchResult(self.docids[idx], score, vector)
+                                  for score, idx, vector in zip(distances, indexes, vectors) if idx != -1]
+                            for key, distances, indexes, vectors in zip(q_ids, D, I, V)}
+        else:
+            D, I = self.index.search(q_embs, k)
+            return {key: [DenseSearchResult(self.docids[idx], score)
+                          for score, idx in zip(distances, indexes) if idx != -1]
+                    for key, distances, indexes in zip(q_ids, D, I)}
 
     def load_index(self, index_dir: str):
         index_path = os.path.join(index_dir, 'index')
@@ -462,10 +533,12 @@ class BinaryDenseSearcher(SimpleDenseSearcher):
         Path to faiss index directory.
     """
 
-    def __init__(self, index_dir: str, query_encoder: Union[QueryEncoder, str], prebuilt_index_name: Optional[str] = None):
+    def __init__(self, index_dir: str, query_encoder: Union[QueryEncoder, str],
+                 prebuilt_index_name: Optional[str] = None):
         super().__init__(index_dir, query_encoder, prebuilt_index_name)
 
-    def search(self, query: str, k: int = 10, binary_k: int = 100, rerank: bool = True, threads: int = 1) -> List[DenseSearchResult]:
+    def search(self, query: str, k: int = 10, binary_k: int = 100, rerank: bool = True, threads: int = 1) \
+            -> List[DenseSearchResult]:
         """Search the collection.
 
         Parameters
@@ -490,7 +563,7 @@ class BinaryDenseSearcher(SimpleDenseSearcher):
         sparse_emb_q = ret['sparse']
         assert len(dense_emb_q) == self.dimension
         assert len(sparse_emb_q) == self.dimension
-        
+
         dense_emb_q = dense_emb_q.reshape((1, len(dense_emb_q)))
         sparse_emb_q = sparse_emb_q.reshape((1, len(sparse_emb_q)))
         faiss.omp_set_num_threads(threads)
@@ -500,8 +573,8 @@ class BinaryDenseSearcher(SimpleDenseSearcher):
         return [DenseSearchResult(str(idx), score)
                 for score, idx in zip(distances, indexes) if idx != -1]
 
-    def batch_search(self, queries: List[str], q_ids: List[str], k: int = 10, binary_k: int = 100, \
-            rerank: bool = True, threads: int = 1) -> Dict[str, List[DenseSearchResult]]:
+    def batch_search(self, queries: List[str], q_ids: List[str], k: int = 10, binary_k: int = 100,
+                     rerank: bool = True, threads: int = 1) -> Dict[str, List[DenseSearchResult]]:
         """
 
         Parameters
@@ -566,7 +639,7 @@ class BinaryDenseSearcher(SimpleDenseSearcher):
             indexes = indexes.reshape(num_queries, -1)[:, :k]
             distances = distances[np.arange(num_queries)[:, None], sorted_indices][:, :k]
         return distances, indexes
-    
+
     def load_index(self, index_dir: str):
         index_path = os.path.join(index_dir, 'index')
         index = faiss.read_index_binary(index_path)
