@@ -27,7 +27,7 @@ from tqdm import tqdm
 
 from pyserini.encoded_query_info import QUERY_INFO
 from pyserini.evaluate_script_info import EVALUATION_INFO
-from pyserini.prebuilt_index_info import INDEX_INFO, DINDEX_INFO
+from pyserini.prebuilt_index_info import TF_INDEX_INFO, FAISS_INDEX_INFO, IMPACT_INDEX_INFO
 
 
 # https://gist.github.com/leimao/37ff6e990b3226c2c9670a2cd1e4a6f5
@@ -158,10 +158,12 @@ def download_and_unpack_index(url, index_directory='indexes', local_filename=Fal
 
 
 def check_downloaded(index_name):
-    if index_name in INDEX_INFO:
-        target_index = INDEX_INFO[index_name]
+    if index_name in TF_INDEX_INFO:
+        target_index = TF_INDEX_INFO[index_name]
+    elif index_name in IMPACT_INDEX_INFO:
+        target_index = IMPACT_INDEX_INFO[index_name]
     else:
-        target_index = DINDEX_INFO[index_name]
+        target_index = FAISS_INDEX_INFO[index_name]
     index_url = target_index['urls'][0]
     index_md5 = target_index['md5']
     index_name = index_url.split('/')[-1]
@@ -173,7 +175,17 @@ def check_downloaded(index_name):
 
 
 def get_sparse_indexes_info():
-    df = pd.DataFrame.from_dict(INDEX_INFO)
+    df = pd.DataFrame.from_dict({**TF_INDEX_INFO, **IMPACT_INDEX_INFO})
+    for index in df.keys():
+        df[index]['downloaded'] = check_downloaded(index)
+
+    with pd.option_context('display.max_rows', None, 'display.max_columns',
+                           None, 'display.max_colwidth', -1, 'display.colheader_justify', 'left'):
+        print(df)
+
+
+def get_impact_indexes_info():
+    df = pd.DataFrame.from_dict(IMPACT_INDEX_INFO)
     for index in df.keys():
         df[index]['downloaded'] = check_downloaded(index)
 
@@ -183,7 +195,7 @@ def get_sparse_indexes_info():
 
 
 def get_dense_indexes_info():
-    df = pd.DataFrame.from_dict(DINDEX_INFO)
+    df = pd.DataFrame.from_dict(FAISS_INDEX_INFO)
     for index in df.keys():
         df[index]['downloaded'] = check_downloaded(index)
 
@@ -193,12 +205,14 @@ def get_dense_indexes_info():
 
 
 def download_prebuilt_index(index_name, force=False, verbose=True, mirror=None):
-    if index_name not in INDEX_INFO and index_name not in DINDEX_INFO:
+    if index_name not in TF_INDEX_INFO and index_name not in FAISS_INDEX_INFO and index_name not in IMPACT_INDEX_INFO:
         raise ValueError(f'Unrecognized index name {index_name}')
-    if index_name in INDEX_INFO:
-        target_index = INDEX_INFO[index_name]
+    if index_name in TF_INDEX_INFO:
+        target_index = TF_INDEX_INFO[index_name]
+    elif index_name in IMPACT_INDEX_INFO:
+        target_index = IMPACT_INDEX_INFO[index_name]
     else:
-        target_index = DINDEX_INFO[index_name]
+        target_index = FAISS_INDEX_INFO[index_name]
     index_md5 = target_index['md5']
     for url in target_index['urls']:
         local_filename = target_index['filename'] if 'filename' in target_index else None
@@ -236,6 +250,6 @@ def download_evaluation_script(evaluation_name, force=False, verbose=True, mirro
 
 
 def get_sparse_index(index_name):
-    if index_name not in DINDEX_INFO:
+    if index_name not in FAISS_INDEX_INFO:
         raise ValueError(f'Unrecognized index name {index_name}')
-    return DINDEX_INFO[index_name]["texts"]
+    return FAISS_INDEX_INFO[index_name]["texts"]
