@@ -1,5 +1,5 @@
 #
-# Pyserini: Python interface to the Anserini IR toolkit built on Lucene
+# Pyserini: Reproducible IR research with sparse and dense representations
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,16 +14,16 @@
 # limitations under the License.
 #
 
-import unittest
 import os
 import shutil
+import unittest
+
 from pyserini.search import SimpleSearcher
 
 
 class TestIndexDownload(unittest.TestCase):
 
     def test_default_cache(self):
-        os.unsetenv('PYSERINI_CACHE')
         SimpleSearcher.from_prebuilt_index('cacm')
         self.assertTrue(os.path.exists(os.path.expanduser('~/.cache/pyserini/indexes')))
 
@@ -35,3 +35,4 @@ class TestIndexDownload(unittest.TestCase):
     def tearDown(self):
         if os.path.exists('temp_dir'):
             shutil.rmtree('temp_dir')
+            os.environ['PYSERINI_CACHE'] = ''
